@@ -34,13 +34,10 @@
 #include <QDBusInterface>
 #include <QDBusMessage>
 #include <QDBusReply>
-#include <QDesktopWidget>
 #include <QDir>
 #include <QDirIterator>
-#include <QIcon>
 #include <QKeyEvent>
 #include <QMenuBar>
-#include <QMetaType>
 #include <QScreen>
 #include <QStatusBar>
 #include <QTime>
